@@ -12,9 +12,7 @@ from cStringIO import StringIO
 from random import random
 from urllib import quote
 
-# Change this to get HTTP instead of the default HTTPS
-#class HTTP(httplib0.HTTP):
-class HTTP(httplib0.HTTPS):
+class HTTP(httplib0.HTTP):
     # A revised version of the HTTP class that can do basic
     # HTTP 1.1 connections, and also compensates for a bug
     # that occurs on some platforms in 1.5 and 1.5.1 with
@@ -48,6 +46,39 @@ class HTTP(httplib0.HTTPS):
         headers =mimetools.Message(self.file, 0)
         return ver, code, msg, headers
 
+class HTTPS(httplib0.HTTPS):
+    # A revised version of the HTTP class that can do basic
+    # HTTP 1.1 connections, and also compensates for a bug
+    # that occurs on some platforms in 1.5 and 1.5.1 with
+    # socket.makefile().read()
+
+    read_bug=sys.version[:5] in ('1.5 (','1.5.1')
+
+    def putrequest(self, request, selector, ver='1.1'):
+        selector=selector or '/'
+        str = '%s %s HTTP/%s\r\n' % (request, selector, ver)
+        self.send(str)
+
+    def getreply(self):
+        file=self.sock.makefile('rb')
+        data=string.join(file.readlines(), '')
+        file.close()
+        self.file=StringIO(data)
+        line = self.file.readline()
+        try:
+            [ver, code, msg] = string.split(line, None, 2)
+        except ValueError:
+            try:
+                [ver, code] = string.split(line, None, 1)
+                msg = ""
+            except ValueError:
+                return -1, line, None
+        if ver[:5] != 'HTTP/':
+            return -1, line, None
+        code=string.atoi(code)
+        msg =string.strip(msg)
+        headers =mimetools.Message(self.file, 0)
+        return ver, code, msg, headers
 
 class Resource:
     """An object representing a web resource."""
@@ -59,9 +90,13 @@ class Resource:
 
         mo = urlreg.match(url)
         if mo:
-            host,port,uri=mo.group(1,2,3)
+            proto,host,port,uri=mo.group(1,2,3,4)
+            self.proto=proto
             self.host=host
-            self.port=port and string.atoi(port[1:]) or 80
+            if proto == 'http':
+                self.port=port and string.atoi(port[1:]) or 80
+            else:
+                self.port=port and string.atoi(port[1:]) or 443
             self.uri=uri or '/'
         else: raise ValueError, url
 
@@ -112,7 +147,10 @@ class Resource:
 
     def __snd_request(self, method, uri, headers={}, body='', eh=1):
         try:
-            h=HTTP()
+            if self.proto == 'http':
+                h=HTTP()
+            else:
+                h=HTTPS()
             h.connect(self.host, self.port)
             h.putrequest(method, uri)
             for n, v in headers.items():
@@ -324,13 +362,6 @@ class Resource:
 
     __repr__=__str__
 
-
-
-
-
-
-
-
 class http_response:
     def __init__(self, ver, code, msg, headers, body):
         self.version=ver
@@ -359,7 +390,6 @@ class http_response:
         data.append(self.body)
         return string.join(data, '')
 
-
 set_xml="""<?xml version="1.0" encoding="utf-8"?>
    <d:propertyupdate xmlns:d="DAV:"
    xmlns:z="http://www.zope.org/propsets/default">
@@ -419,13 +449,10 @@ find_xml="""<?xml version="1.0" encoding="utf-8" ?>
    </D:propfind>
 """
 
-
-
 ##############################################################################
 # Implementation details below here
 
-
-urlreg=re.compile(r'http://([^:/]+)(:[0-9]+)?(/.+)?', re.I)
+urlreg=re.compile(r'(http|https)://([^:/]+)(:[0-9]+)?(/.+)?', re.I)
 
 def marshal_string(name, val):
     return '%s=%s' % (name, quote(str(val)))
@@ -470,8 +497,6 @@ for name, tp, func in vartypes:
 def marshal_var(name, val):
     return varfuncs.get(type(val), marshal_string)(name, val)
 
-
-
 class MultiPart:
     def __init__(self,*args):
         c=len(args)
@@ -600,7 +625,6 @@ class MultiPart:
              'application/octet-stream': 'binary',
              }
 
-
 bri =Resource('http://tarzan.digicool.com/dev/brian3/',
               username='brian',
               password='123')
@@ -610,3 +634,5 @@ dav =Resource('http://tarzan.digicool.com/dev/dav/',
               username='brian',
               password='123')
 adav=Resource('http://tarzan.digicool.com/dev/dav/')
+
+# ex: set tabstop=4 expandtab:
